==> vtigercrm-5.2.1p2.tgz: modules/Reports/language/de_de.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): www.crm-now.de translation to German
 ********************************************************************************/
/*********************************************************************************
 * $Header: 
 * Description:  Defines the German language pack for the Report module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): crm-now, Berlin, www.crm-now.com
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Berichte',
'LBL_MODULE_TITLE'=>'Berichte: Home',
'LBL_CREATE_REPORT'=>'Bericht erstellen',
'LBL_CUSTOMIZE_REPORT'=>'Bericht anpassen',
'LBL_REP_BUTTON'=>'Erstelle neuen Bericht',
'LBL_REP_FOLDER_BUTTON'=>'Erstelle neuen Berichtsordner',
'LBL_REP_FOLDER'=>'Berichtsordner',
'LBL_REP_FOLDER_DTLS'=>'Ordnerdetails',
'LBL_REP_FOLDER_NAME'=>'Ordnername:',
'LBL_REP_FOLDER_DESC'=>'Beschreiben:',
'LBL_NEW_REP0_HDR1'=>'Modul wählen, für das ein neuer Bericht erstellt wird:',
'LBL_NEW_REP0_HDR2'=>'Wähle zugehöriges Modul:',
'LBL_NEW_REP0_HDR3'=>'Notiz:',
'LBL_NEW_REP0_HDR4'=>'Berichts-Modul und zugehöriges Modul können später nicht mehr geändert werden!',
'LBL_CONTINUE_BUTTON'=>'Weiter',
'LBL_NEW_REP1_HDR1'=>'Bitte folgende Berichtsinformationen ausfüllen',
'LBL_SELECT_COLUMNS'=>'Spalten wählen',
'LBL_SPECIFY_GROUPING'=>'Gruppierung',
'LBL_COLUMNS_TO_TOTAL'=>'Spalten für die Summenbildung wählen',
'LBL_SPECIFY_CRITERIA'=>'Kriterien setzen',
'LBL_SAVERUN_BUTTON'=>'Speichern und Ausführen',
'LBL_TABULAT_REPORT'=>'tabellarischer Bericht',
'LBL_REPORT_TYPE_HDR1'=>'Tabellarische Berichte sind der einfachste und schnellste Weg um eine Auflistung aller Daten zu erhalten.',
'LBL_SUMMARY_REPORT'=>'zusammenfassender Bericht',
'LBL_REPORT_TYPE_HDR2'=>'Zusammenfassende Berichte erlauben die Auflistung der Daten mit Zwischensummen.',
'LBL_AVAILABLE_COLUMNS'=>'verfügbare Spalten:',
'LBL_SELECTED_COLUMNS'=>'gewählte Spalten:',
'LBL_ADD_BUTTON'=>'hinzufügen',
'LBL_COLUMNS'=>'Spalten',
'LBL_COLUMNS_SUM'=>'Summe',
'LBL_COLUMNS_AVERAGE'=>'Durchschnitt',
'LBL_COLUMNS_LOW_VALUE'=>'kleinster Wert',
'LBL_COLUMNS_LARGE_VALUE'=>'größter Wert',
'LBL_NONE'=>'ohne',
'LBL_GROUPING_SORT'=>'Sortierung:',
'LBL_GROUPING_SUMMARIZE'=>'Zwischensumme nach:',
'LBL_GROUPING_THEN_BY'=>'und dann nach:',
'LBL_GROUPING_FINALLY_BY'=>'und letztlich nach:',
'LBL_ADVANCED_FILTER'=>'erweiterte Filter',
'LBL_STANDARD_FILTER'=>'Standardfilter',
'LBL_SF_COLUMNS'=>'Spalte',
'LBL_SF_STARTDATE'=>'Startdatum',
'LBL_SF_ENDDATE'=>'Enddatum',
'LBL_AF_HDR1'=>'Setzen Sie Suchkriterien um die Resultatsliste zu begrenzen.',
'LBL_AF_HDR2'=>'Sie können &quot;or&quot; Filter durch die Eingabe mehrerer Einträge in der dritten Spalte setzen.',
'LBL_AF_HDR3'=>'Sie können bis zu 10 durch Komma getrennte Werte eingeben. Bsp.: SG, ZH, TG, AR sucht nach SG oder ZH oder TG oder AR.',
'LBL_FILTER_OPTIONS'=>'Filteroptionen',
'LBL_CUSTOMIZE_BUTTON'=>'Anpassen',
'LBL_EXPORTPDF_BUTTON'=>'erstelle PDF',
'LBL_APPLYFILTER_BUTTON'=>'Filter aktivieren',
'LBL_GENERATED_REPORT'=>'Erstellter Bericht',
'LBL_GRAND_TOTAL'=>'Gesamtsumme',

//Added for 4.2 Patch I
'LBL_EXPORTXL_BUTTON'=>'Export zu Excel',

//Added for 5 Beta
'LBL_NO_PERMISSION'=>'Ihr Profil berechtigt Sie nicht den Bericht von einem dieser Module zu sehen.',
'LBL_SELECT_COLUMNS_TO_GENERATE_REPORTS'=>'Bitte Spalten auswählen.',
'LBL_AVAILABLE_FIELDS'=>'verfügbare Felder',
'LBL_SELECTED_FIELDS'=>'ausgewählte Felder',
'LBL_CALCULATIONS'=>'Berechnungen',
'LBL_SELECT_COLUMNS_TO_TOTAL'=>'Spalten für Total auswählen.',
'LBL_SELECT_FILTERS_TO_STREAMLINE_REPORT_DATA'=>'Filter auswählen',
'LBL_SELECT_FILTERS'=>'Filter',
'LBL_SELECT_COLUMNS_TO_GROUP_REPORTS'=>'Spalten auswählen um Berichte zu gruppieren',
'LBL_BACK_TO_REPORTS'=>'zurück zu Berichte',
'LBL_SELECT_ANOTHER_REPORT'=>'einen anderen Bericht auswählen',
'LBL_SELECT_COLUMN'=>'Spalte auswählen',
'LBL_SELECT_TIME'=>'Zeit auswählen',
'LBL_PRINT_REPORT'=>'Bericht drucken',
'LBL_CLICK_HERE'=>'Hier klicken',
'LBL_TO_ADD_NEW_GROUP'=>'um eine Berichtsgruppe zu erstellen.',
'LBL_CREATE_NEW'=>'neu',
'LBL_RELATIVE_MODULE'=>'relative Module',
'LBL_REPORT_TYPE'=>'Berichtstype',
'LBL_REPORT_DETAILS'=>'Berichtsdetails',
'LBL_TYPE_THE_NAME'=>'Namen eingeben',
'LBL_DESCRIPTION_FOR_REPORT'=>'Berichtsbeschreibung',
'LBL_REPORT_NAME'=>'Berichtsname',
'LBL_DESCRIPTION'=>'Beschreibung',
'LBL_TOOLS'=>'Werkzeuge',
'LBL_AND'=>'und',
'LBL_ADD_NEW_GROUP'=>'neue Berichtsgruppe:',
'LBL_REPORT_MODULE'=>'Berichtsmodule',
'LBL_SELECT_RELATIVE_MODULE_FOR_REPORT'=>'relatives Modul für Bericht auswählen',
'LBL_SELECT_REPORT_TYPE_BELOW'=>'unten Berichtstyp auswählen',
'LBL_TABULAR_FORMAT'=>'Tabellenformat',
'LBL_TABULAR_REPORTS_ARE_SIMPLEST'=>' 	Tabellarische Berichte sind der einfachste und schnellste Weg um eine Auflistung aller Daten zu erhalten.',
'LBL_SUMMARY_REPORT_VIEW_DATA_WITH_SUBTOTALS'=>'Zusammenfassende Berichte erlauben die Auflistung der Daten mit Zwischensummen.',
'LBL_FILTERS'=>'Filter',
'LBL_MOVE_TO'=>'verschiebe zu',
'LBL_RENAME_FOLDER'=>'Ordner umbenennen',
'LBL_DELETE_FOLDER'=>'Ordner löschen',

'Account and Contact Reports'=>'Organisations- und Personenberichte',
'Lead Reports'=>'Lead-Berichte',
'Potential Reports'=>'Potentialberichte',
'Activity Reports'=>'Aktivitätenberichte',
'HelpDesk Reports'=>'Trouble Tickets Berichte',
'Product Reports'=>'Produktberichte',
'Quote Reports'=>'Angebotsberichte',
'PurchaseOrder Reports'=>'Einkaufsbestellungsberichte',
'SalesOrder Reports'=>'Verkaufsbestellungsberichte', //Added for SO
'Invoice Reports'=>'Rechnungsberichte',
'Campaign Reports'=>'Kampagnenberichte', //Added for Campaigns
'Contacts by Accounts'=>'Personen nach Organisationen',
'Contacts without Accounts'=>'Personen ohne Organisationen',
'Contacts by Potentials'=>'Personen nach Potentialen',
'Contacts related to Accounts'=>'Personen bezogen auf Orgnisationen',
'Contacts not related to Accounts'=>'Personen ohne Bezug auf Organisationen',
'Contacts related to Potentials'=>'Personen bezogen auf Potentiale',
'Lead by Source'=>'Lead nach Quellen',
'Lead Status Report'=>'Lead-Statusbericht',
'Potential Pipeline'=>'Potentialpipeline',
'Closed Potentials'=>'geschlossene Potentiale',
'Potential that have Won'=>'abgeschlossene Geschäfte',
'Tickets by Products'=>'Tickets nach Produkten',
'Tickets by Priority'=>'Tickets nach Priorität',
'Open Tickets'=>'Offene Tickets',
'Tickets related to Products'=>'Tickets bezogen auf Producte',
'Tickets that are Open'=>'offene Tickets',
'Product Details'=>'Produktdetails',
'Products by Contacts'=>'Produkte nach Personen',
'Product Detailed Report'=>'Produktdetailbericht',
'Products related to Contacts'=>'Produkte bezogen auf Personen',
'Open Quotes'=>'offene Angebote',
'Quotes Detailed Report'=>'detailierter Angebotsbericht',
'Quotes that are Open'=>'offene Angebote',
'PurchaseOrder by Contacts'=>'Verkaufsbestellung nach Personen',
'PurchaseOrder Detailed Report'=>'detaillierter Bericht über Verkaufsbestellungen',
'PurchaseOrder related to Contacts'=>'Verkaufsbestellung bezogen auf Personen',
'Invoice Detailed Report'=>'detaillierter Bericht über Rechnungen',
'Last Month Activities'=>'Aktivitäten des letzten Monats',
'This Month Activities'=>'Aktivitäten aus diesem Monat',
'Campaign Expectations and Actuals'=>'Kampagnenerwartungen und aktuelles', //Added for Campaigns
'SalesOrder Detailed Report'=>'detaillierter Verkaufsbestellungenbericht', //Added for SO

'LBL_DELETE'=>'Löschen',
'Create_Reports'=>'neuen Bericht erzeugen',
'Create_New_Folder'=>'neuen Ordner erzeugen',
'Move_Reports'=>'Bericht verschieben',
'Delete_Report'=>'Bericht löschen',

'Custom'=>'benutzerdefiniert',
'Previous FY'=>'vorheriges Jahr',
'Current FY'=>'dieses Jahr',
'Next FY'=>'nächstes Jahr',
'Previous FQ'=>'vorheriges Quartal',
'Current FQ'=>'dieses Quartal',
'Next FQ'=>'nächstes Quartal',
'Yesterday'=>'gestern',
'Today'=>'heute',
'Tomorrow'=>'morgen',
'Last Week'=>'letzte Woche',
'Current Week'=>'jetzige Woche',
'Next Week'=>'nächste Woche',
'Last Month'=>'letzter Monat',
'Current Month'=>'jetziger Monat',
'Next Month'=>'nächster Monat',
'Last 7 Days'=>'letzte 7 Tage',
'Last 30 Days'=>'letzte 30 Tage',
'Last 60 Days'=>'letzte 60 Tage',
'Last 90 Days'=>'letzte 90 Tage',
'Last 120 Days'=>'letzte 120 Tage',
'Next 7 Days'=>'nächste 7 Tage',
'Next 30 Days'=>'nächste 30 Tage',
'Next 60 Days'=>'nächste 60 Tage',
'Next 90 Days'=>'nächste 90 Tage',
'Next 120 Days'=>'nächste 120 Tage',
'TITLE_VTIGERCRM_CREATE_REPORT' => 'Bericht erzeugen',
'TITLE_VTIGERCRM_PRINT_REPORT' => 'Bericht drucken',
'NO_FILTER_SELECTED' => 'ohne Filterauswahl',

'LBL_GENERATE_NOW'=>'jetzt Aktualisieren',
'Totals'=>'Feldnamen',
'SUM'=>'Summe',
'AVG'=>'Durchschnitt',
'MAX'=>'Maximum',
'MIN'=>'Minimum',
'LBL_CUSTOM_REPORTS'=>'benutzerdefinierte Berichte',

'ticketid'=>'Ticket ID',
'NO_COLUMN'=>'Für die Total Spalte sind keine Daten verfügbar.',

// Added/Updated for vtiger CRM 5.0.4
'LBL_REPORT_DELETED' => 'Dieser Bericht wude bereits gelöscht.',

//Added for Reports
'LBL_SHARING'=>'Mitbenutzung',
'SELECT_FILTER_TYPE'=>'Berichtstyp auswählen',
'LBL_USERS'=>'CRM Nutzer',
'LBL_GROUPS'=>'Gruppen',
'LBL_SELECT_FIELDS'=>'Felder auswählen',
'LBL_MEMBERS'=>'Mitglieder',
'LBL_RELATED_FIELDS'=>'bezogene Felder',
'LBL_NO_ACCESS'=>' Zugang gesperrt: ',
'LBL_NOT_ACTIVE'=>' Zugang nicht freigegeben: ',
'LBL_PERM_DENIED'=>' Keine Rechte für die Berichte vorhanden: ',
'LBL_FLDR_NOT_EMPTY'=>'Das Verzeichnis, was Sie löschen wollen ist nicht leer.  Leeren Sie das Verzeichnis zuerst.',
'NO_REL_MODULES'=>'Für das ausgewählte Modul gibt es keine bezogene Module',
'LBL_REPORT_GENERATION_FAILED'=>'Fehler bei der Berichtserstellung!',

'LBL_OR'=>'oder',
'LBL_NEW_GROUP'=>'neue Gruppe',
'LBL_DELETE_GROUP'=>'Gruppe löschen',
'LBL_NEW_CONDITION'=>'neue Bedingung',
'LBL_SHARING_TYPE'=>'Berichtstyp',
'LBL_SELECT_REPORT_TYPE_TO_CONTROL_ACCESS'=>'Wählen Sie einen Berichtstyp um die Zugangsrechte zum Bericht zu setzen.', 
'LBL_ACTION' => 'Aktion',
'LBL_VIEW_DETAILS' => 'Details ansehen',
'LBL_SHOW_STANDARD_FILTERS' => 'zeige Standardfilter',
)

?>

==> vtigercrm-5.3.0p0.tgz: modules/Reports/language/de_de.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Berichte',
'LBL_MODULE_TITLE'=>'Berichte: Home',
'LBL_CREATE_REPORT'=>'Bericht erstellen',
'LBL_CUSTOMIZE_REPORT'=>'Bericht anpassen',
'LBL_REP_BUTTON'=>'Erstelle neuen Bericht',
'LBL_REP_FOLDER_BUTTON'=>'Erstelle neuen Berichtsordner',
'LBL_REP_FOLDER'=>'Berichtsordner',
'LBL_REP_FOLDER_DTLS'=>'Ordnerdetails',
'LBL_REP_FOLDER_NAME'=>'Ordnername:',
'LBL_REP_FOLDER_DESC'=>'Beschreiben:',
'LBL_NEW_REP0_HDR1'=>'Modul wählen, für das ein neuer Bericht erstellt wird:',
'LBL_NEW_REP0_HDR2'=>'Wähle zugehöriges Modul:',
'LBL_NEW_REP0_HDR3'=>'Notiz:',
'LBL_NEW_REP0_HDR4'=>'Berichts-Modul und zugehöriges Modul können später nicht mehr geändert werden!',
'LBL_CONTINUE_BUTTON'=>'Weiter',
'LBL_NEW_REP1_HDR1'=>'Bitte folgende Berichtsinformationen ausfüllen',
'LBL_SELECT_COLUMNS'=>'Spalten wählen',
'LBL_SPECIFY_GROUPING'=>'Gruppierung',
'LBL_COLUMNS_TO_TOTAL'=>'Spalten für die Summenbildung wählen',
'LBL_SPECIFY_CRITERIA'=>'Kriterien setzen',
'LBL_SAVERUN_BUTTON'=>'Speichern und Ausführen',
'LBL_TABULAT_REPORT'=>'tabellarischer Bericht',
'LBL_REPORT_TYPE_HDR1'=>'Tabellarische Berichte sind der einfachste und schnellste Weg um eine Auflistung aller Daten zu erhalten.',
'LBL_SUMMARY_REPORT'=>'zusammenfassender Bericht',
'LBL_REPORT_TYPE_HDR2'=>'Zusammenfassende Berichte erlauben die Auflistung der Daten mit Zwischensummen.',
'LBL_AVAILABLE_COLUMNS'=>'verfügbare Spalten:',
'LBL_SELECTED_COLUMNS'=>'gewählte Spalten:',
'LBL_ADD_BUTTON'=>'hinzufügen',
'LBL_COLUMNS'=>'Spalten',
'LBL_COLUMNS_SUM'=>'Summe',
'LBL_COLUMNS_AVERAGE'=>'Durchschnitt',
'LBL_COLUMNS_LOW_VALUE'=>'kleinster Wert',
'LBL_COLUMNS_LARGE_VALUE'=>'größter Wert',
'LBL_NONE'=>'ohne',
'LBL_GROUPING_SORT'=>'Sortierung:',
'LBL_GROUPING_SUMMARIZE'=>'Zwischensumme nach:',
'LBL_GROUPING_THEN_BY'=>'und dann nach:',
'LBL_GROUPING_FINALLY_BY'=>'und letztlich nach:',
'LBL_ADVANCED_FILTER'=>'erweiterte Filter',
'LBL_STANDARD_FILTER'=>'Standardfilter',
'LBL_SF_COLUMNS'=>'Spalte',
'LBL_SF_STARTDATE'=>'Startdatum',
'LBL_SF_ENDDATE'=>'Enddatum',
'LBL_AF_HDR1'=>'Setzen Sie Suchkriterien um die Resultatsliste zu begrenzen.',
'LBL_AF_HDR2'=>'Sie können &quot;or&quot; Filter durch die Eingabe mehrerer Einträge in der dritten Spalte setzen.',
'LBL_AF_HDR3'=>'Sie können bis zu 10 durch Komma getrennte Werte eingeben. Bsp.: SG, ZH, TG, AR sucht nach SG oder ZH oder TG oder AR.',
'LBL_FILTER_OPTIONS'=>'Filteroptionen',
'LBL_CUSTOMIZE_BUTTON'=>'Anpassen',
'LBL_EXPORTPDF_BUTTON'=>'erstelle PDF',
'LBL_APPLYFILTER_BUTTON'=>'Filter aktivieren',
'LBL_GENERATED_REPORT'=>'Erstellter Bericht',
'LBL_GRAND_TOTAL'=>'Gesamtsumme',

//Added for 4.2 Patch I
'LBL_EXPORTXL_BUTTON'=>'Export zu Excel',

//Added for 5 Beta
'LBL_NO_PERMISSION'=>'Ihr Profil berechtigt Sie nicht den Bericht von einem dieser Module zu sehen.',
'LBL_SELECT_COLUMNS_TO_GENERATE_REPORTS'=>'Bitte Spalten auswählen.',
'LBL_AVAILABLE_FIELDS'=>'verfügbare Felder',
'LBL_SELECTED_FIELDS'=>'ausgewählte Felder',
'LBL_CALCULATIONS'=>'Berechnungen',
'LBL_SELECT_COLUMNS_TO_TOTAL'=>'Spalten für Total auswählen.',
'LBL_SELECT_FILTERS_TO_STREAMLINE_REPORT_DATA'=>'Filter auswählen',
'LBL_SELECT_FILTERS'=>'Filter',
'LBL_SELECT_COLUMNS_TO_GROUP_REPORTS'=>'Spalten auswählen um Berichte zu gruppieren',
'LBL_BACK_TO_REPORTS'=>'zurück zu Berichte',
'LBL_SELECT_ANOTHER_REPORT'=>'einen anderen Bericht auswählen',
'LBL_SELECT_COLUMN'=>'Spalte auswählen',
'LBL_SELECT_TIME'=>'Zeit auswählen',
'LBL_PRINT_REPORT'=>'Bericht drucken',
'LBL_CLICK_HERE'=>'Hier klicken',
'LBL_TO_ADD_NEW_GROUP'=>'um eine Berichtsgruppe zu erstellen.',
'LBL_CREATE_NEW'=>'neu',
'LBL_RELATIVE_MODULE'=>'relative Module',
'LBL_REPORT_TYPE'=>'Berichtstype',
'LBL_REPORT_DETAILS'=>'Berichtsdetails',
'LBL_TYPE_THE_NAME'=>'Namen eingeben',
'LBL_DESCRIPTION_FOR_REPORT'=>'Berichtsbeschreibung',
'LBL_REPORT_NAME'=>'Berichtsname',
'LBL_DESCRIPTION'=>'Beschreibung',
'LBL_TOOLS'=>'Werkzeuge',
'LBL_AND'=>'und',
'LBL_ADD_NEW_GROUP'=>'neue Berichtsgruppe:',
'LBL_REPORT_MODULE'=>'Berichtsmodule',
'LBL_SELECT_RELATIVE_MODULE_FOR_REPORT'=>'relatives Modul für Bericht auswählen',
'LBL_SELECT_REPORT_TYPE_BELOW'=>'unten Berichtstyp auswählen',
'LBL_TABULAR_FORMAT'=>'Tabellenformat',
'LBL_TABULAR_REPORTS_ARE_SIMPLEST'=>' 	Tabellarische Berichte sind der einfachste und schnellste Weg um eine Auflistung aller Daten zu erhalten.',
'LBL_SUMMARY_REPORT_VIEW_DATA_WITH_SUBTOTALS'=>'Zusammenfassende Berichte erlauben die Auflistung der Daten mit Zwischensummen.',
'LBL_FILTERS'=>'Filter',
'LBL_MOVE_TO'=>'verschiebe zu',
'LBL_RENAME_FOLDER'=>'Ordner umbenennen',
'LBL_DELETE_FOLDER'=>'Ordner löschen',

'Account and Contact Reports'=>'Organisations- und Personenberichte',
'Lead Reports'=>'Lead-Berichte',
'Potential Reports'=>'Potentialberichte',
'Activity Reports'=>'Aktivitätenberichte',
'HelpDesk Reports'=>'Trouble Tickets Berichte',
'Product Reports'=>'Produktberichte',
'Quote Reports'=>'Angebotsberichte',
'PurchaseOrder Reports'=>'Einkaufsbestellungsberichte',
'SalesOrder Reports'=>'Verkaufsbestellungsberichte', //Added for SO
'Invoice Reports'=>'Rechnungsberichte',
'Campaign Reports'=>'Kampagnenberichte', //Added for Campaigns
'Contacts by Accounts'=>'Personen nach Organisationen',
'Contacts without Accounts'=>'Personen ohne Organisationen',
'Contacts by Potentials'=>'Personen nach Potentialen',
'Contacts related to Accounts'=>'Personen bezogen auf Orgnisationen',
'Contacts not related to Accounts'=>'Personen ohne Bezug auf Organisationen',
'Contacts related to Potentials'=>'Personen bezogen auf Potentiale',
'Lead by Source'=>'Lead nach Quellen',
'Lead Status Report'=>'Lead-Statusbericht',
'Potential Pipeline'=>'Potentialpipeline',
'Closed Potentials'=>'geschlossene Potentiale',
'Potential that have Won'=>'abgeschlossene Geschäfte',
'Tickets by Products'=>'Tickets nach Produkten',
'Tickets by Priority'=>'Tickets nach Priorität',
'Open Tickets'=>'Offene Tickets',
'Tickets related to Products'=>'Tickets bezogen auf Producte',
'Tickets that are Open'=>'offene Tickets',
'Product Details'=>'Produktdetails',
'Products by Contacts'=>'Produkte nach Personen',
'Product Detailed Report'=>'Produktdetailbericht',
'Products related to Contacts'=>'Produkte bezogen auf Personen',
'Open Quotes'=>'offene Angebote',
'Quotes Detailed Report'=>'detailierter Angebotsbericht',
'Quotes that are Open'=>'offene Angebote',
'PurchaseOrder by Contacts'=>'Verkaufsbestellung nach Personen',
'PurchaseOrder Detailed Report'=>'detaillierter Bericht über Verkaufsbestellungen',
'PurchaseOrder related to Contacts'=>'Verkaufsbestellung bezogen auf Personen',
'Invoice Detailed Report'=>'detaillierter Bericht über Rechnungen',
'Last Month Activities'=>'Aktivitäten des letzten Monats',
'This Month Activities'=>'Aktivitäten aus diesem Monat',
'Campaign Expectations and Actuals'=>'Kampagnenerwartungen und aktuelles', //Added for Campaigns
'SalesOrder Detailed Report'=>'detaillierter Verkaufsbestellungenbericht', //Added for SO

'LBL_DELETE'=>'Löschen',
'Create_Reports'=>'neuen Bericht erzeugen',
'Create_New_Folder'=>'neuen Ordner erzeugen',
'Move_Reports'=>'Bericht verschieben',
'Delete_Report'=>'Bericht löschen',

'Custom'=>'benutzerdefiniert',
'Previous FY'=>'vorheriges Jahr',
'Current FY'=>'dieses Jahr',
'Next FY'=>'nächstes Jahr',
'Previous FQ'=>'vorheriges Quartal',
'Current FQ'=>'dieses Quartal',
'Next FQ'=>'nächstes Quartal',
'Yesterday'=>'gestern',
'Today'=>'heute',
'Tomorrow'=>'morgen',
'Last Week'=>'letzte Woche',
'Current Week'=>'jetzige Woche',
'Next Week'=>'nächste Woche',
'Last Month'=>'letzter Monat',
'Current Month'=>'jetziger Monat',
'Next Month'=>'nächster Monat',
'Last 7 Days'=>'letzte 7 Tage',
'Last 30 Days'=>'letzte 30 Tage',
'Last 60 Days'=>'letzte 60 Tage',
'Last 90 Days'=>'letzte 90 Tage',
'Last 120 Days'=>'letzte 120 Tage',
'Next 7 Days'=>'nächste 7 Tage',
'Next 30 Days'=>'nächste 30 Tage',
'Next 60 Days'=>'nächste 60 Tage',
'Next 90 Days'=>'nächste 90 Tage',
'Next 120 Days'=>'nächste 120 Tage',
'TITLE_VTIGERCRM_CREATE_REPORT' => 'Bericht erzeugen',
'TITLE_VTIGERCRM_PRINT_REPORT' => 'Bericht drucken',
'NO_FILTER_SELECTED' => 'ohne Filterauswahl',

'LBL_GENERATE_NOW'=>'jetzt Aktualisieren',
'Totals'=>'Feldnamen',
'SUM'=>'Summe',
'AVG'=>'Durchschnitt',
'MAX'=>'Maximum',
'MIN'=>'Minimum',
'LBL_CUSTOM_REPORTS'=>'benutzerdefinierte Berichte',

'ticketid'=>'Ticket ID',
'NO_COLUMN'=>'Für die Total Spalte sind keine Daten verfügbar.',

// Added/Updated for vtiger CRM 5.0.4
'LBL_REPORT_DELETED' => 'Dieser Bericht wude bereits gelöscht.',

//Added for Reports
'LBL_SHARING'=>'Mitbenutzung',
'SELECT_FILTER_TYPE'=>'Berichtstyp auswählen',
'LBL_USERS'=>'CRM Nutzer',
'LBL_GROUPS'=>'Gruppen',
'LBL_SELECT_FIELDS'=>'Felder auswählen',
'LBL_MEMBERS'=>'Mitglieder',
'LBL_RELATED_FIELDS'=>'bezogene Felder',
'LBL_NO_ACCESS'=>' Zugang gesperrt: ',
'LBL_NOT_ACTIVE'=>' Zugang nicht freigegeben: ',
'LBL_PERM_DENIED'=>' Keine Rechte für die Berichte vorhanden: ',
'LBL_FLDR_NOT_EMPTY'=>'Das Verzeichnis, was Sie löschen wollen ist nicht leer.  Leeren Sie das Verzeichnis zuerst.',
'NO_REL_MODULES'=>'Für das ausgewählte Modul gibt es keine bezogene Module',
'LBL_REPORT_GENERATION_FAILED'=>'Fehler bei der Berichtserstellung!',

'LBL_OR'=>'oder',
'LBL_NEW_GROUP'=>'neue Gruppe',
'LBL_DELETE_GROUP'=>'Gruppe löschen',
'LBL_NEW_CONDITION'=>'neue Bedingung',
'LBL_SHARING_TYPE'=>'Berichtstyp',
'LBL_SELECT_REPORT_TYPE_TO_CONTROL_ACCESS'=>'Wählen Sie einen Berichtstyp um die Zugangsrechte zum Bericht zu setzen.', 
'LBL_ACTION' => 'Aktion',
'LBL_VIEW_DETAILS' => 'Details ansehen',
'LBL_SHOW_STANDARD_FILTERS' => 'zeige Standardfilter',

'LBL_YEAR' => 'Jahr',
'LBL_MONTH'=> 'Monat',
'LBL_QUARTER'=> 'Quartal',
'LBL_NONE'=> 'Keine',

'LBL_ROLES'=>'Rollen',
'LBL_ROLES_SUBORDINATES'=>'Rollen und Unterrollen',
'LBL_SCHEDULE_EMAIL'=>'Email Versandplanung',
'LBL_SCHEDULE_EMAIL_DESCRIPTION'=>'Zeitplan nach dem der Bericht an ausgewählte Email Empfänger gesendet werden soll.',
'LBL_USERS_AVAILABEL'=> 'Empfänger',
'LBL_REPORT_FORMAT_PDF'=> 'PDF',
'LBL_REPORT_FORMAT_EXCEL'=> 'EXCEL',
'LBL_REPORT_FORMAT_BOTH'=> 'Beides',
'LBL_REPORT_FORMAT'=> 'Berichtsformat',
'LBL_USERS_SELECTED'=>'Ausgewählte Empfänger',
'LBL_SELECT'=>'Selektieren',
'Hourly'=>'Stündlich',
'Daily'=>'Täglich',
'Weekly'=>'Wöchentlich',
'BiWeekly'=>'alle zwei Wochen',
'Monthly'=>'Monatlich',
'Annually'=>'Jährlich',
'LBL_SCHEDULE_REPORT'=>'Zeitplanung',
'LBL_SCHEDULE_FREQUENCY'=>'Frequenz',
'OPTION_SCHEDULE_EMAIL_CHOOSE'=>'Wählen ..... ',
'LBL_SCHEDULE_EMAIL_TIME'=>'Uhrzeit',
'LBL_SCHEDULE_EMAIL_DOW'=>'Wochentag',
'LBL_SCHEDULE_EMAIL_DAY'=>'Tag',
'LBL_SCHEDULE_EMAIL_MONTH'=>'Monat',
'WEEKDAY_STRINGS' => array('Sonntag','Montag','Dienstag','Mittwoch','Donnerstag','Freitag','Samstag'),
'MONTH_STRINGS' => array('Januar','Februar','März','April','Mai','Juni','Juli','August','September','Oktober','November','Dezember'),

'LBL_AUTO_GENERATED_REPORT_EMAIL' => 'Dies ist eine automatisch generierte E-Mail aufgrund eines Bericht-Zeitplans.',
'LBL_TIME_FORMAT_MSG' => 'hh:mm (24 Stunden Format)',

'LBL_SAVE_REPORT' => 'Speichern',
'LBL_SAVE_REPORT_AS' => 'Bericht Speichern als...',
);

?>
